""" Distributor init file

Distributors: you can add custom code here to support particular distributions
of numpy.

For example, this is a good place to put any BLAS/LAPACK initialization code.

The numpy standard source distribution will not put code in this file, so you
can safely replace this file with your own version.
"""

try:
    from . import _distributor_init_local
except ImportError:
    pass

try:
    import contextlib
    import os
    from importlib import metadata

    # Add MKL library to DLL search path on Windows so mkl-service can find it.
    with contextlib.suppress(AttributeError, FileNotFoundError, StopIteration):
        dll = next(p for p in metadata.files("mkl") if p.match("*mkl_rt*.dll"))
        dll_dir = dll.locate().resolve().parent
        os.add_dll_directory(dll_dir)

    # Load MKL library via mkl-service so we don't have to graft it into NumPy.
    import mkl

except (ImportError, metadata.PackageNotFoundError):
    import warnings

    warnings.warn(
        "Failed to import mkl-service. Please install it or manually add the MKL "
        "library to LD_LIBRARY_PATH",
        stacklevel=2,
    )
